<!-- TITLE -->
<br />
<div align="center">
  <a href="https://github.com/github_username/repo_name">
    <a href="https://freeimage.host/i/QExVpf"><img src="https://iili.io/QExVpf.md.png" alt="QExVpf.md.png" border="0"></a>
  </a>

  <p align="center">
    Python program that can transform a suite of Moodle Question data 
    <br>
    in a format specified by the client to Moodle XML and back.
  </p>
</div>

<br>

<!-- ABOUT THE PROJECT -->
## About The Project
The process to write CodeRunner questions with Moodle is difficult and the number of options makes question creation long and tedious. This means that teaching staff spend large amounts of time working simply writing out the questions, and the process leads to a high incidence of question errors.

Based on <a href="https://github.com/James-Ansley/moodle-toml">Moodle TOML</a> by James-Ansley, Finale supports various question types (including CodeRunner, short answer, multiple choice, etc.) and provide warnings for common errors in generating questions. Also, Finale supports question templates to generate questions in a consistent and precise format.

<br>

### Built With

* Python
* Moodle
* XML

<br>

<!-- USAGE EXAMPLES -->
## Usage



<br>

<!-- ACKNOWLEDGMENTS -->
## Acknowledgments
* Moodle TOML (@James-Ansley): https://github.com/James-Ansley/moodle-toml
* Best-README-Template (@othneildrew): https://github.com/othneildrew/Best-README-Template